@@ -1,6 +1,6 @@
 use std::collections::VecDeque;
 
-use smoltcp::phy::{ChecksumCapabilities, Device, DeviceCapabilities, Medium, RxToken, TxToken};
+use smoltcp::phy::{Device, DeviceCapabilities, Medium, RxToken, TxToken};
 use smoltcp::time::Instant;
 
 use tokio::sync::mpsc::{Permit, Sender};
@@ -56,7 +56,6 @@ impl<'a> Device<'a> for VirtualDevice {
 
     fn capabilities(&self) -> DeviceCapabilities {
         let mut capabilities = DeviceCapabilities::default();
-        capabilities.checksum = ChecksumCapabilities::ignored();
         capabilities.medium = Medium::Ip;
         capabilities.max_transmission_unit = 1420;
         capabilities
@@ -76,7 +75,9 @@ impl<'a> TxToken for VirtualTxToken<'a> {
         let result = f(&mut buffer);
 
         if result.is_ok() {
-            let cmd = NetworkCommand::SendPacket(IpPacket::try_from(buffer).map_err(|_| smoltcp::Error::Malformed)?);
+            let cmd = NetworkCommand::SendPacket(
+                IpPacket::try_from(buffer).map_err(|_| smoltcp::Error::Malformed)?,
+            );
             self.permit.send(cmd);
         }
         result
