@@ -33,6 +33,7 @@ pub struct TcpStream {
     peername: SocketAddr,
     sockname: SocketAddr,
     original_dst: SocketAddr,
+    is_closing: bool,
 }
 
 #[pymethods]
@@ -81,7 +82,8 @@ impl TcpStream {
     }
 
     /// Close the stream after flushing the write buffer.
-    fn write_eof(&self) -> PyResult<()> {
+    fn write_eof(&mut self) -> PyResult<()> {
+        self.is_closing = true;
         self.event_tx
             .send(TransportCommand::CloseConnection(self.connection_id, true))
             .map_err(event_queue_unavailable)?;
@@ -90,7 +92,8 @@ impl TcpStream {
     }
 
     /// Close the TCP stream and the underlying socket immediately.
-    fn close(&self) -> PyResult<()> {
+    fn close(&mut self) -> PyResult<()> {
+        self.is_closing = true;
         self.event_tx
             .send(TransportCommand::CloseConnection(self.connection_id, false))
             .map_err(event_queue_unavailable)?;
@@ -98,11 +101,21 @@ impl TcpStream {
         Ok(())
     }
 
+    /// Check whether this TCP stream is being closed.
+    fn is_closing(&self) -> PyResult<bool> {
+        Ok(self.is_closing)
+    }
+
     /// Query the TCP stream for details of the underlying network connection.
     ///
     /// Supported values: `peername`, `sockname`, `original_dst`.
     #[args(default = "None")]
-    fn get_extra_info(&self, py: Python, name: String, default: Option<PyObject>) -> PyResult<PyObject> {
+    fn get_extra_info(
+        &self,
+        py: Python,
+        name: String,
+        default: Option<PyObject>,
+    ) -> PyResult<PyObject> {
         match (name.as_str(), default) {
             ("peername", _) => Ok(socketaddr_to_py(py, self.peername)),
             ("sockname", _) => Ok(socketaddr_to_py(py, self.sockname)),
@@ -137,7 +150,7 @@ pub fn socketaddr_to_py(py: Python, s: SocketAddr) -> PyObject {
                 (addr.ip().to_string(), addr.port())
             );
             (addr.ip().to_string(), addr.port()).into_py(py)
-        },
+        }
     }
 }
 
@@ -211,6 +224,7 @@ impl PyInteropTask {
                                     peername: src_addr,
                                     sockname: self.local_addr,
                                     original_dst: dst_addr,
+                                    is_closing: false,
                                 };
 
                                 Python::with_gil(|py| {
